@@ -33,6 +33,8 @@ let MAX_WIDTH = 600;
 let MAX_HEIGHT = 450;
 let MAX_ROWS = 20;
 let MAX_COLS = 20;
+let LEFT_PADDING = 50;
+let MARGIN_NUMBER_CIRCLE = 2;
 export class WorldModel {
   rows: number;
   cols: number;
@@ -46,6 +48,8 @@ export class WorldModel {
   tileMap: any;
   tiles: any;
   pending_goals: any;
+  drop_goals: any;
+
   ui: {
     wrapper: HTMLDivElement;
     stage?: Konva.Stage;
@@ -70,7 +74,8 @@ export class WorldModel {
     objects = {},
     tileMap = {},
     tiles = [],
-    pending_goals = []
+    pending_goals = [],
+    drop_goals = []
   ) {
     this.rows = Math.min(MAX_ROWS, rows);
     this.cols = Math.min(MAX_COLS, cols);
@@ -86,6 +91,7 @@ export class WorldModel {
     this.tileMap = tileMap;
     this.tiles = tiles;
     this.pending_goals = pending_goals;
+    this.drop_goals = drop_goals;
     this.draw_canvas();
 
     this.robots = robots.map(
@@ -162,6 +168,8 @@ export class WorldModel {
     this.draw_objects();
     this.draw_msg_containers();
 
+    this.draw_drop_goals(this.drop_goals);
+
     if (this.pending_goals.length > 0) {
       this.draw_pending_instructions(this.pending_goals, 'red');
     } else {
@@ -314,29 +322,70 @@ export class WorldModel {
     this.ui.layers.main.draw();
   }
 
-  draw_custom(obj_name: string, x: number, y: number, val: number) {
+  draw_custom(
+    obj_name: string,
+    x: number,
+    y: number,
+    val: number,
+    isGoal: boolean = false
+  ) {
     let imagePath = this.tileMap[obj_name];
-    let [cx, cy] = this.point2cxy(x + 1, y);
-    Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
-      node.setAttrs({
-        x: cx + this.bs / 2 - 10,
-        y: cy - this.bs / 2,
-        width: this.bs - 10,
-        height: this.bs - 10,
-        name: `obj-${x}-${y}-img`,
-      });
-      this.ui.layers.main.add(node);
-      this.ui.layers.main.batchDraw();
+    let [cx, cy] = this.point2cxy(x, y);
+
+    let radius = (0.4 * this.bs) / 2;
+    let group = new Konva.Group({
+      x: cx + LEFT_PADDING + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
+      y: cy - this.bs / 2 + (this.bs - radius) - MARGIN_NUMBER_CIRCLE,
     });
 
-    let num = new Konva.Text({
-      text: `${val}`,
-      x: cx + 32,
-      y: cy + 2,
-      fontSize: 16,
-      name: `obj-${x}-${y}-text`,
+    if (!isGoal) {
+      let circle = new Konva.Circle({
+        radius: radius,
+        fill: 'white',
+        stroke: '#aaa',
+        opacity: 0.9,
+      });
+
+      let TEXT_MARGIN =
+        val > 9 ? MARGIN_NUMBER_CIRCLE : 2 * MARGIN_NUMBER_CIRCLE;
+      let fontSize = Math.ceil((this.bs * 14) / 50); // when bs = 50 fontSize=14
+      let num = new Konva.Text({
+        text: `${val}`,
+        fontSize: fontSize,
+        name: `obj-${x}-${y}-text`,
+        offsetX: circle.x() + radius - TEXT_MARGIN,
+        offsetY: circle.y() + radius - TEXT_MARGIN,
+      });
+
+      group.add(circle, num);
+    }
+
+    Konva.Image.fromURL(imagePath, (node: Konva.Image) => {
+      node.setAttrs({
+        x: cx + LEFT_PADDING,
+        y: cy - this.bs / 2,
+        width: this.bs,
+        height: this.bs,
+        name: `obj-${x}-${y}-img`,
+      });
+
+      if (isGoal) {
+        node.cache();
+        node.filters([Konva.Filters.Grayscale]);
+        this.ui.layers.main.add(node);
+      } else {
+        this.ui.layers.main.add(node);
+        this.ui.layers.main.add(group);
+      }
+      this.ui.layers.main.batchDraw();
+    });
+  }
+
+  draw_drop_goals(goals = []) {
+    goals.map((goal) => {
+      //@ts-ignore
+      this.draw_custom(goal.obj_name, goal.x, goal.y, goal.val, true);
     });
-    this.ui.layers.main.add(num);
   }
 
   parse_value(val: number | string) {
