@@ -96,7 +96,8 @@ export class MazeView extends DOMWidgetView {
     objects: any = {},
     tileMap: any = {},
     tiles: any = [],
-    pending_goals: any = []
+    pending_goals: any = [],
+    drop_goals: any = []
   ) => {
     return this.world_model.init(
       rows,
@@ -107,7 +108,8 @@ export class MazeView extends DOMWidgetView {
       objects,
       tileMap,
       tiles,
-      pending_goals
+      pending_goals,
+      drop_goals
     );
   };
 
@@ -139,6 +141,10 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.draw_object(x, y, { [obj_name]: val });
   };
 
+  add_goal_object = (x: number, y: number, obj_name: string, val: number) => {
+    return this.world_model.draw_custom(obj_name, x, y, val, true);
+  };
+
   update_object = (x: number, y: number, val: number) => {
     return this.world_model.update_object(x, y, val);
   };
