@@ -287,6 +287,43 @@ class Robot():
         else:
             return None
     
+    def carries_object(self):
+        """Check if the bot has collected any objects.
+
+        Returns
+        -------
+        bool
+            Returns True if the bot has any object collected.
+            False otherwise.
+
+        Examples
+        --------
+        >>> bot.carries_object()
+        True
+        """
+
+        return len(self.basket()) > 0
+
+    def basket(self):
+        """Returns the list of objects picked by the robot.
+
+        Returns
+        -------
+        array
+            Returns the list of objects picked by the robot.
+
+        Examples
+        --------
+        >>> bot.basket()
+        ["apple"]
+        """
+
+        if(len(self.last_picked) > 0):
+            return [x[0] for x in self.last_picked]
+        else:
+            return []
+
+    
     def at_goal(self):
         """Checks if the bot is at its goal position.
 
@@ -311,7 +348,10 @@ class Robot():
         return False
     
     def put(self):
-        
+        cell = self.cell()
+        if not cell.editable["drop"]:
+            raise RuntimeError("Can't drop to this Cell")
+
         self.world_model.incr_instruction()
         if len(self.last_picked) > 0:
             [o_name, ck] = self.last_picked.pop()
@@ -350,6 +390,10 @@ class Robot():
         >>> bot.take()
         """
         self.world_model.incr_instruction()
+        cell = self.cell()
+        if not cell.editable["pick"]:
+            raise RuntimeError("Can't Pick From this Cell")
+
         if self.on_object(obj_type):
             ck = "{},{}".format(self.x,self.y)
         
